// RBC Model with C_Aggregate-Corporations vs Pass-Through
// Created: 25 August 2021
// Last Revision: 29 Octobre 2021
// Features: Cobb-Douglas Utility, Exogeneous Labor Supply, Bonus Depreciation only on New Investment
// Parameterization for US in 2017
// C_Aggregate-Corps are numeraire

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
var C_PT, C_Corp, Y_PT, Y_Corp, K_PT, K_Corp, W_PT, W_Corp, p, C_bundle, MU, MU_Corp, MU_PT, lambda, SDF, P_PT, D_PT, P_Corp, D_Corp, 
pi_Corp, I_Corp, MPL_Corp, MPK_Corp, L_Corp, L_PT,
pi_PT, I_PT, MPL_PT, MPK_PT, ID_pi, K_pi, K_pi_new, TB_pi, q, mu, mu_new,
T, T_Corp, T_II, G, Transfer, before_reform,
C_Aggregate, I_Aggregate, Y_Aggregate, L_Aggregate;

varexo tau_pi, after_reform;


parameters beta, sigma, gamma, L_Corp_exo, L_PT_exo,
alpha_Corp, alpha_PT, delta_Corp, delta_PT, A_Corp, A_PT,
tau_pi_initial, delta_pi_before, delta_pi_after, tau_II, theta;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%% Calibration %%%%%%

% Household Parameters
beta  = 0.94;
sigma = (1)^(-1);
gamma = 0.575; 
L_Corp_exo = 0.575;
L_PT_exo = 1 - L_Corp_exo;

% Productive-Sector Parameters
alpha_Corp = 0.35;
alpha_PT = 0.35;
delta_Corp = 0.10;
delta_PT = 0.10;
A_Corp = 1;
A_PT = 1;

% Government Parameters
delta_pi_before = 0.4823;
delta_pi_after = 0.8305;
tau_pi_initial = 0.35;
tau_II = 0.135;
theta = 0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

model;

%%%%%%%%%%%%%%%%%% HOUSEHOLD PROBLEM %%%%%%%%%%%%%%%%%%%%%%  

% Definitions
C_bundle = C_Corp^(gamma) * C_PT^(1 - gamma);
MU = C_bundle^(-sigma);
MU_Corp = gamma * MU * (C_PT/C_Corp)^(1 - gamma);
MU_PT = (1 - gamma) * MU * (C_Corp/C_PT)^(gamma);
lambda = MU_Corp;
SDF = beta * lambda(+1)/lambda;
MU_Corp = MU_PT/p;

% Labor Supply
L_Corp = L_Corp_exo;
L_PT = L_PT_exo;

% HH's Euler Equations
1 = SDF * ((P_PT(+1) + (1 - tau_II) * D_PT(+1)) / P_PT);
1 = SDF * ((P_Corp(+1) + (1 - tau_II) * D_Corp(+1)) / P_Corp);


% HH's Budget Constraint
C_Corp + p * C_PT =  (W_Corp * L_Corp + W_PT * L_PT  + D_Corp + D_PT) - T_II + Transfer;



%%%%%%%%%%%%%%%%%% C-CORPORATIONS PROBLEM %%%%%%%%%%%%%%%%%%%%%%  

% Definition of Profit, Dividend and Corporate Taxes
D_Corp = pi_Corp - T_Corp;
pi_Corp = Y_Corp - W_Corp * L_Corp - I_Corp;
TB_pi = Y_Corp - W_Corp * L_Corp - ID_pi;
T_Corp = tau_pi * TB_pi;


% Tax Depreciation Schedule
ID_pi = I_Corp * (delta_pi_before * before_reform + delta_pi_after * after_reform) + delta_pi_before * K_pi(-1) + delta_pi_after * K_pi_new(-1);
K_pi = (1 - delta_pi_before) * ( before_reform * I_Corp + K_pi(-1) );
K_pi_new = (1 - delta_pi_after) * ( after_reform * I_Corp + K_pi_new(-1) );



% Capital Law of Motion
K_Corp = (1 - delta_Corp) * K_Corp(-1) + I_Corp;


% Production Function
Y_Corp = A_Corp * K_Corp(-1)^(alpha_Corp) * L_Corp^(1-alpha_Corp);
MPL_Corp = A_Corp * (1 - alpha_Corp) * L_Corp^(-alpha_Corp) * K_Corp(-1)^(alpha_Corp);
MPK_Corp = A_Corp * alpha_Corp * K_Corp(-1)^(alpha_Corp - 1) * L_Corp^(1 - alpha_Corp);


% Optimal Labor Demand
MPL_Corp = W_Corp;


% Euler Equation for Investment
1 = q + tau_pi * (before_reform * delta_pi_before + after_reform * delta_pi_after) + before_reform * mu * (1 - delta_pi_before) + after_reform * mu_new * (1 - delta_pi_after);

% Euler Equation for Economic Capital Stock
q = SDF * ( q(+1) * (1 - delta_Corp) + (1 - tau_pi) * MPK_Corp(+1) );

% Euler Equation for Tax Capital Stock Before Reform
mu = SDF * ( mu(+1) * (1 - delta_pi_before) + tau_pi * delta_pi_before );

% Euler Equation for Tax Capital Stock After Reform
mu_new = SDF * ( mu_new(+1) * (1 - delta_pi_after) + tau_pi * delta_pi_after );


%%%%%%%%%%%%%%%%%% PASS-THROUGH PROBLEM %%%%%%%%%%%%%%%%%%%%%%  

% Definition of Profit, and Dividend 
D_PT = pi_PT;
pi_PT = p * Y_PT - W_PT * L_PT - p * I_PT;

% Capital Law of Motion
K_PT = (1 - delta_PT) * K_PT(-1) + I_PT;


% Production Function
Y_PT = A_PT * K_PT(-1)^(alpha_PT) * L_PT^(1-alpha_PT);
MPL_PT = A_PT * (1 - alpha_PT) * L_PT^(-alpha_PT) * K_PT(-1)^(alpha_PT);
MPK_PT = A_PT * alpha_PT * K_PT(-1)^(alpha_PT - 1) * L_PT^(1 - alpha_PT);

% Optimal Labor Demand
MPL_PT * p = W_PT;

% Euler Equation for Investment
1 = SDF * ( p(+1)/p ) * (1 - delta_PT + MPK_PT(+1) )  ;


%%%%%%%%%%%%%%%%%% GOVERNMENT %%%%%%%%%%%%%%%%%%%%%%  
T_II =  tau_II  * (W_Corp * L_Corp + W_PT * L_PT  + D_Corp + D_PT);
T = T_Corp + T_II;

G = theta * T;
Transfer = (1 - theta) * T;


% auxiliary indicator variable
before_reform = 1 - after_reform; 

%%%%%%%%%%%%%%%%%% MARKET CLEARING %%%%%%%%%%%%%%%%%%%%%%  

Y_Corp = C_Corp + I_Corp;



%%%%%%%%%%%%%%%%%% AGGREGATION %%%%%%%%%%%%%%%%%%%%%%  
Y_Aggregate = Y_Corp + p * Y_PT;
C_Aggregate = C_Corp + p * C_PT;
I_Aggregate = I_Corp + p * I_PT;
L_Aggregate = L_Corp + L_PT;

end;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%





%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
initval;
// Exogeneous Variables
tau_pi = tau_pi_initial;
after_reform = 0;

// Endogeneous Variables
K_Corp = 3;
K_PT = 3;
p = 1;

q = 1;
mu = 0.3;
mu_new = 0.3;

L_PT = L_PT_exo;
L_Corp = L_Corp_exo;
L_Aggregate = L_PT + L_Corp;

Y_Corp = A_Corp * K_Corp^(alpha_Corp) * L_Corp^(1-alpha_Corp);
Y_PT = A_PT * K_PT^(alpha_PT) * L_PT^(1-alpha_PT);
Y_Aggregate = Y_Corp + p * Y_PT;

I_Corp = delta_Corp * K_Corp;
I_PT = delta_PT * K_PT;
I_Aggregate = I_Corp + p * I_PT;



MPK_Corp = A_Corp * alpha_Corp * K_Corp^(alpha_Corp - 1) * L_Corp^(1 - alpha_Corp);
MPL_Corp = A_Corp * (1 - alpha_Corp) * L_Corp^(-alpha_Corp) * K_Corp^(alpha_Corp);

MPK_PT = A_PT * alpha_PT * K_PT^(alpha_PT - 1) * L_PT^(1 - alpha_PT);
MPL_PT = A_PT * (1 - alpha_PT) * L_PT^(-alpha_PT) * K_PT^(alpha_PT);

W_Corp = MPL_Corp;
W_PT = MPL_PT;

C_PT = Y_PT - I_PT;
C_Corp =  Y_Corp - I_Corp;
C_Aggregate = C_Corp + p * C_PT;

C_bundle = C_Corp^(gamma) * C_PT^(1 - gamma);
MU = C_bundle^(-sigma);
MU_Corp = gamma * MU * (C_PT/C_Corp)^(1 - gamma);
MU_PT = (1 - gamma) * MU * (C_Corp/C_PT)^(gamma);
lambda = MU_Corp;
SDF = beta;

P_Corp = K_Corp;
P_PT = K_PT;

pi_Corp = Y_Corp - W_Corp * L_Corp - I_Corp;
T_Corp = tau_pi * TB_pi;
TB_pi = Y_Corp - W_Corp * L_Corp - ID_pi;

ID_pi = I_Corp * (delta_pi_before * before_reform + delta_pi_after * after_reform) + delta_pi_before * K_pi + delta_pi_after * K_pi_new;
K_pi = (1 - delta_pi_before) * (I_Corp * before_reform + K_pi );
K_pi_new = (1 - delta_pi_after) * (I_Corp * after_reform + K_pi_new );

D_Corp = pi_Corp - T_Corp;

pi_PT = p * Y_PT - W_PT * L_PT - p * I_PT;
D_PT = pi_PT;


T_II =  tau_II  * (W_Corp * L_Corp + W_PT * L_PT  + D_Corp + D_PT);
T = T_Corp + T_II;

G = theta * T;
Transfer = (1 - theta) * T;


end;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

